#!/usr/bin/env python
"""
Create an HTML index for the instructions.
"""
__author__ = 'Martin Blais <blais@furius.ca>'
__copyright__ = 'BSD'

import csv, os, re
from os.path import *


def main():
    import optparse
    parser = optparse.OptionParser(__doc__.strip())
    opts, args = parser.parse_args()
    if len(args) != 2:
        parser.error("Usage: [] []... ")
    fn, output = args

    with open(join(output, 'index.html'), 'w') as index:
        print index.name
        def wr(x):
            index.write(x)
            index.write('\n')
        wr('<html><body>')
        wr('<h1>Intel Manual - Opcodes Reference</h1>')
        wr('<ul>')
        for op, srange, desc in csv.reader(open(fn)):
            filename = '%s/%s.html' % (op, op)
            wr('<li><a href="%s"><b>%s</b> - %s</a></li>' % (filename, op, desc))
        wr('</body></html>')

        for op, srange, desc in csv.reader(open(fn)):
            filename = '%s/%s.html' % (op, op)
            dn = join(output, op)
            with open(join(output, filename), 'w') as f:
                print f.name
                def wr(x):
                    f.write(x)
                    f.write('\n')

                wr('<html><body>')
                wr('<a href="../index.html" style="float: right">[index]</a>')
                wr('<style>' + noselect + '</style>')
                wr('<h1>%s</h1>' % op)
                for png in sorted(os.listdir(dn)):
                    if not re.match('.*\.png$', png): continue
                    wr('<img src="%s" width="100%%" class="unselectable" />' % png)
                wr('</body></html>')

noselect = """
.unselectable {
-webkit-user-select: none;
-khtml-user-select: none;
-moz-user-select: none;
-o-user-select: none;
user-select: none;
}
"""


if __name__ == '__main__':
    main()
