#!/usr/bin/env python
"""
Create an index of the PDF file with the list of desired opcodes.
"""
__author__ = 'Martin Blais <blais@furius.ca>'
__copyright__ = 'BSD'

import sys, re, csv
from os.path import *
import poppler


def walk_index_(ii, doc, index):
    "Walk the PDF document index."
    while ii.next():
        act = ii.get_action()
        if act.dest.named_dest is None:
            continue
        page = int(doc.find_dest(act.dest.named_dest).page_num)
        index.append( (act.title, page) )
        child = ii.get_child()
        if child:
            walk_index_(child, doc, index)

def walk_index(doc):
    index = []
    walk_index_(poppler.IndexIter(doc), doc, index)
    return index

def iterpairs(l):
    i = iter(l)
    prev = i.next()
    for e in i:
        yield (prev, e)
        prev = e

def main():
    import optparse
    parser = optparse.OptionParser(__doc__.strip())
    opts, args = parser.parse_args()

    f = csv.writer(sys.stdout)
    if 1:
        for fn in args:
            doc = poppler.document_new_from_file('file://%s' % abspath(fn), None)
            index = walk_index(doc)
            prev = None
            for (title1, p1), (title2, p2) in iterpairs(index):
                srange = "%s-%s" % (p1,p2-1)
                mo = re.match(r'([^\-.,]+)-(.*)', title1)
                if mo:
                    operand = re.sub('[ /\[\]]', '_', mo.group(1)).strip('_')
                    desc = mo.group(2)
                    f.writerow( (operand, srange, desc) )
                else:
                    print >> sys.stderr,  "##### %-48s %s" % (title1, srange)


if __name__ == '__main__':
    main()
